# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['paddlepaddle-stubs',
 'paddlepaddle-stubs.examples',
 'paddlepaddle-stubs.tests',
 'paddlepaddle-stubs.tests.test_nn',
 'paddlepaddle-stubs.tests.test_nn.test_layer',
 'paddlepaddle-stubs.tests.test_optimizer',
 'paddlepaddle-stubs.tests.test_tensor',
 'paddlepaddle-stubs.tests.test_vision',
 'paddlepaddle-stubs.tests.test_vision.test_models',
 'paddlepaddle-stubs.tests.test_vision.test_transforms']

package_data = \
{'': ['*'],
 'paddlepaddle-stubs': ['.git/*',
                        '.git/hooks/*',
                        '.git/info/*',
                        '.git/logs/*',
                        '.git/logs/refs/heads/*',
                        '.git/logs/refs/remotes/origin/*',
                        '.git/objects/00/*',
                        '.git/objects/01/*',
                        '.git/objects/02/*',
                        '.git/objects/03/*',
                        '.git/objects/04/*',
                        '.git/objects/05/*',
                        '.git/objects/06/*',
                        '.git/objects/07/*',
                        '.git/objects/08/*',
                        '.git/objects/09/*',
                        '.git/objects/0a/*',
                        '.git/objects/0b/*',
                        '.git/objects/0c/*',
                        '.git/objects/0d/*',
                        '.git/objects/0e/*',
                        '.git/objects/0f/*',
                        '.git/objects/10/*',
                        '.git/objects/11/*',
                        '.git/objects/12/*',
                        '.git/objects/13/*',
                        '.git/objects/14/*',
                        '.git/objects/15/*',
                        '.git/objects/16/*',
                        '.git/objects/17/*',
                        '.git/objects/18/*',
                        '.git/objects/19/*',
                        '.git/objects/1a/*',
                        '.git/objects/1b/*',
                        '.git/objects/1c/*',
                        '.git/objects/1d/*',
                        '.git/objects/1e/*',
                        '.git/objects/1f/*',
                        '.git/objects/20/*',
                        '.git/objects/21/*',
                        '.git/objects/22/*',
                        '.git/objects/23/*',
                        '.git/objects/24/*',
                        '.git/objects/25/*',
                        '.git/objects/26/*',
                        '.git/objects/27/*',
                        '.git/objects/28/*',
                        '.git/objects/29/*',
                        '.git/objects/2a/*',
                        '.git/objects/2b/*',
                        '.git/objects/2c/*',
                        '.git/objects/2d/*',
                        '.git/objects/2e/*',
                        '.git/objects/2f/*',
                        '.git/objects/30/*',
                        '.git/objects/31/*',
                        '.git/objects/32/*',
                        '.git/objects/33/*',
                        '.git/objects/34/*',
                        '.git/objects/35/*',
                        '.git/objects/36/*',
                        '.git/objects/37/*',
                        '.git/objects/38/*',
                        '.git/objects/39/*',
                        '.git/objects/3a/*',
                        '.git/objects/3b/*',
                        '.git/objects/3c/*',
                        '.git/objects/3d/*',
                        '.git/objects/3e/*',
                        '.git/objects/3f/*',
                        '.git/objects/40/*',
                        '.git/objects/41/*',
                        '.git/objects/42/*',
                        '.git/objects/43/*',
                        '.git/objects/44/*',
                        '.git/objects/45/*',
                        '.git/objects/46/*',
                        '.git/objects/47/*',
                        '.git/objects/48/*',
                        '.git/objects/49/*',
                        '.git/objects/4a/*',
                        '.git/objects/4b/*',
                        '.git/objects/4c/*',
                        '.git/objects/4d/*',
                        '.git/objects/4e/*',
                        '.git/objects/4f/*',
                        '.git/objects/50/*',
                        '.git/objects/51/*',
                        '.git/objects/52/*',
                        '.git/objects/53/*',
                        '.git/objects/54/*',
                        '.git/objects/55/*',
                        '.git/objects/56/*',
                        '.git/objects/57/*',
                        '.git/objects/58/*',
                        '.git/objects/59/*',
                        '.git/objects/5a/*',
                        '.git/objects/5b/*',
                        '.git/objects/5c/*',
                        '.git/objects/5d/*',
                        '.git/objects/5e/*',
                        '.git/objects/5f/*',
                        '.git/objects/60/*',
                        '.git/objects/61/*',
                        '.git/objects/62/*',
                        '.git/objects/63/*',
                        '.git/objects/64/*',
                        '.git/objects/65/*',
                        '.git/objects/66/*',
                        '.git/objects/67/*',
                        '.git/objects/68/*',
                        '.git/objects/69/*',
                        '.git/objects/6a/*',
                        '.git/objects/6b/*',
                        '.git/objects/6c/*',
                        '.git/objects/6d/*',
                        '.git/objects/6e/*',
                        '.git/objects/6f/*',
                        '.git/objects/70/*',
                        '.git/objects/71/*',
                        '.git/objects/72/*',
                        '.git/objects/73/*',
                        '.git/objects/74/*',
                        '.git/objects/75/*',
                        '.git/objects/76/*',
                        '.git/objects/77/*',
                        '.git/objects/78/*',
                        '.git/objects/79/*',
                        '.git/objects/7a/*',
                        '.git/objects/7b/*',
                        '.git/objects/7c/*',
                        '.git/objects/7d/*',
                        '.git/objects/7e/*',
                        '.git/objects/7f/*',
                        '.git/objects/80/*',
                        '.git/objects/81/*',
                        '.git/objects/82/*',
                        '.git/objects/83/*',
                        '.git/objects/84/*',
                        '.git/objects/85/*',
                        '.git/objects/86/*',
                        '.git/objects/87/*',
                        '.git/objects/88/*',
                        '.git/objects/89/*',
                        '.git/objects/8a/*',
                        '.git/objects/8b/*',
                        '.git/objects/8c/*',
                        '.git/objects/8d/*',
                        '.git/objects/8e/*',
                        '.git/objects/8f/*',
                        '.git/objects/90/*',
                        '.git/objects/91/*',
                        '.git/objects/92/*',
                        '.git/objects/93/*',
                        '.git/objects/94/*',
                        '.git/objects/95/*',
                        '.git/objects/96/*',
                        '.git/objects/97/*',
                        '.git/objects/98/*',
                        '.git/objects/99/*',
                        '.git/objects/9a/*',
                        '.git/objects/9b/*',
                        '.git/objects/9c/*',
                        '.git/objects/9d/*',
                        '.git/objects/9e/*',
                        '.git/objects/9f/*',
                        '.git/objects/a0/*',
                        '.git/objects/a1/*',
                        '.git/objects/a2/*',
                        '.git/objects/a3/*',
                        '.git/objects/a4/*',
                        '.git/objects/a5/*',
                        '.git/objects/a6/*',
                        '.git/objects/a7/*',
                        '.git/objects/a8/*',
                        '.git/objects/a9/*',
                        '.git/objects/aa/*',
                        '.git/objects/ab/*',
                        '.git/objects/ac/*',
                        '.git/objects/ad/*',
                        '.git/objects/ae/*',
                        '.git/objects/af/*',
                        '.git/objects/b0/*',
                        '.git/objects/b1/*',
                        '.git/objects/b2/*',
                        '.git/objects/b3/*',
                        '.git/objects/b4/*',
                        '.git/objects/b5/*',
                        '.git/objects/b6/*',
                        '.git/objects/b7/*',
                        '.git/objects/b8/*',
                        '.git/objects/b9/*',
                        '.git/objects/ba/*',
                        '.git/objects/bb/*',
                        '.git/objects/bc/*',
                        '.git/objects/bd/*',
                        '.git/objects/be/*',
                        '.git/objects/bf/*',
                        '.git/objects/c0/*',
                        '.git/objects/c1/*',
                        '.git/objects/c2/*',
                        '.git/objects/c3/*',
                        '.git/objects/c4/*',
                        '.git/objects/c5/*',
                        '.git/objects/c6/*',
                        '.git/objects/c7/*',
                        '.git/objects/c8/*',
                        '.git/objects/c9/*',
                        '.git/objects/ca/*',
                        '.git/objects/cb/*',
                        '.git/objects/cc/*',
                        '.git/objects/cd/*',
                        '.git/objects/ce/*',
                        '.git/objects/cf/*',
                        '.git/objects/d0/*',
                        '.git/objects/d1/*',
                        '.git/objects/d2/*',
                        '.git/objects/d3/*',
                        '.git/objects/d4/*',
                        '.git/objects/d5/*',
                        '.git/objects/d6/*',
                        '.git/objects/d7/*',
                        '.git/objects/d8/*',
                        '.git/objects/d9/*',
                        '.git/objects/da/*',
                        '.git/objects/db/*',
                        '.git/objects/dc/*',
                        '.git/objects/dd/*',
                        '.git/objects/de/*',
                        '.git/objects/df/*',
                        '.git/objects/e0/*',
                        '.git/objects/e1/*',
                        '.git/objects/e2/*',
                        '.git/objects/e3/*',
                        '.git/objects/e4/*',
                        '.git/objects/e5/*',
                        '.git/objects/e6/*',
                        '.git/objects/e7/*',
                        '.git/objects/e8/*',
                        '.git/objects/e9/*',
                        '.git/objects/ea/*',
                        '.git/objects/eb/*',
                        '.git/objects/ec/*',
                        '.git/objects/ed/*',
                        '.git/objects/ee/*',
                        '.git/objects/ef/*',
                        '.git/objects/f0/*',
                        '.git/objects/f1/*',
                        '.git/objects/f2/*',
                        '.git/objects/f3/*',
                        '.git/objects/f4/*',
                        '.git/objects/f5/*',
                        '.git/objects/f6/*',
                        '.git/objects/f7/*',
                        '.git/objects/f8/*',
                        '.git/objects/f9/*',
                        '.git/objects/fa/*',
                        '.git/objects/fb/*',
                        '.git/objects/fc/*',
                        '.git/objects/fd/*',
                        '.git/objects/fe/*',
                        '.git/objects/ff/*',
                        '.git/objects/pack/*',
                        '.git/refs/heads/*',
                        '.git/refs/remotes/origin/*',
                        '.git/refs/tags/*',
                        '.github/*',
                        '.github/workflows/*',
                        '.vscode/*',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/_C_ops.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/__init__.pyi',
                        'paddle-stubs/_typing/*',
                        'paddle-stubs/amp/*',
                        'paddle-stubs/autograd/*',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/batch.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/callbacks.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/check_import_scipy.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/common_ops_import.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/compat.pyi',
                        'paddle-stubs/cost_model/*',
                        'paddle-stubs/dataset/*',
                        'paddle-stubs/device/*',
                        'paddle-stubs/device/cuda/*',
                        'paddle-stubs/distributed/*',
                        'paddle-stubs/distributed/auto_parallel/*',
                        'paddle-stubs/distributed/auto_parallel/cost/*',
                        'paddle-stubs/distributed/auto_parallel/operators/*',
                        'paddle-stubs/distributed/auto_parallel/tuner/*',
                        'paddle-stubs/distributed/fleet/*',
                        'paddle-stubs/distributed/fleet/base/*',
                        'paddle-stubs/distributed/fleet/data_generator/*',
                        'paddle-stubs/distributed/fleet/dataset/*',
                        'paddle-stubs/distributed/fleet/elastic/*',
                        'paddle-stubs/distributed/fleet/meta_optimizers/*',
                        'paddle-stubs/distributed/fleet/meta_optimizers/ascend/*',
                        'paddle-stubs/distributed/fleet/meta_optimizers/dygraph_optimizer/*',
                        'paddle-stubs/distributed/fleet/meta_optimizers/sharding/*',
                        'paddle-stubs/distributed/fleet/meta_parallel/*',
                        'paddle-stubs/distributed/fleet/meta_parallel/parallel_layers/*',
                        'paddle-stubs/distributed/fleet/meta_parallel/pp_utils/*',
                        'paddle-stubs/distributed/fleet/meta_parallel/sharding/*',
                        'paddle-stubs/distributed/fleet/metrics/*',
                        'paddle-stubs/distributed/fleet/runtime/*',
                        'paddle-stubs/distributed/fleet/utils/*',
                        'paddle-stubs/distributed/launch/*',
                        'paddle-stubs/distributed/launch/context/*',
                        'paddle-stubs/distributed/launch/controllers/*',
                        'paddle-stubs/distributed/launch/job/*',
                        'paddle-stubs/distributed/launch/plugins/*',
                        'paddle-stubs/distributed/launch/utils/*',
                        'paddle-stubs/distributed/metric/*',
                        'paddle-stubs/distributed/models/*',
                        'paddle-stubs/distributed/models/moe/*',
                        'paddle-stubs/distributed/passes/*',
                        'paddle-stubs/distributed/ps/*',
                        'paddle-stubs/distributed/ps/utils/*',
                        'paddle-stubs/distributed/sharding/*',
                        'paddle-stubs/distribution/*',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fft.pyi',
                        'paddle-stubs/fluid/*',
                        'paddle-stubs/fluid/contrib/*',
                        'paddle-stubs/fluid/contrib/decoder/*',
                        'paddle-stubs/fluid/contrib/extend_optimizer/*',
                        'paddle-stubs/fluid/contrib/layers/*',
                        'paddle-stubs/fluid/contrib/mixed_precision/*',
                        'paddle-stubs/fluid/contrib/mixed_precision/bf16/*',
                        'paddle-stubs/fluid/contrib/quantize/*',
                        'paddle-stubs/fluid/contrib/slim/*',
                        'paddle-stubs/fluid/contrib/slim/quantization/*',
                        'paddle-stubs/fluid/contrib/slim/quantization/imperative/*',
                        'paddle-stubs/fluid/contrib/sparsity/*',
                        'paddle-stubs/fluid/dataloader/*',
                        'paddle-stubs/fluid/distributed/*',
                        'paddle-stubs/fluid/dygraph/*',
                        'paddle-stubs/fluid/dygraph/amp/*',
                        'paddle-stubs/fluid/dygraph/dygraph_to_static/*',
                        'paddle-stubs/fluid/incubate/*',
                        'paddle-stubs/fluid/incubate/checkpoint/*',
                        'paddle-stubs/fluid/incubate/data_generator/*',
                        'paddle-stubs/fluid/incubate/fleet/*',
                        'paddle-stubs/fluid/incubate/fleet/base/*',
                        'paddle-stubs/fluid/incubate/fleet/collective/*',
                        'paddle-stubs/fluid/incubate/fleet/parameter_server/*',
                        'paddle-stubs/fluid/incubate/fleet/parameter_server/distribute_transpiler/*',
                        'paddle-stubs/fluid/incubate/fleet/parameter_server/ir/*',
                        'paddle-stubs/fluid/incubate/fleet/parameter_server/pslib/*',
                        'paddle-stubs/fluid/incubate/fleet/utils/*',
                        'paddle-stubs/fluid/inference/*',
                        'paddle-stubs/fluid/layers/*',
                        'paddle-stubs/fluid/transpiler/*',
                        'paddle-stubs/fluid/transpiler/details/*',
                        'paddle-stubs/framework/*',
                        'paddle-stubs/hapi/*',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/hub.pyi',
                        'paddle-stubs/incubate/*',
                        'paddle-stubs/incubate/autograd/*',
                        'paddle-stubs/incubate/checkpoint/*',
                        'paddle-stubs/incubate/multiprocessing/*',
                        'paddle-stubs/incubate/nn/*',
                        'paddle-stubs/incubate/nn/functional/*',
                        'paddle-stubs/incubate/nn/layer/*',
                        'paddle-stubs/incubate/operators/*',
                        'paddle-stubs/incubate/optimizer/*',
                        'paddle-stubs/incubate/optimizer/functional/*',
                        'paddle-stubs/incubate/passes/*',
                        'paddle-stubs/incubate/tensor/*',
                        'paddle-stubs/io/*',
                        'paddle-stubs/jit/*',
                        'paddle-stubs/jit/dy2static/*',
                        'paddle-stubs/libs/*',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/linalg.pyi',
                        'paddle-stubs/metric/*',
                        'paddle-stubs/nn/*',
                        'paddle-stubs/nn/functional/*',
                        'paddle-stubs/nn/initializer/*',
                        'paddle-stubs/nn/layer/*',
                        'paddle-stubs/nn/quant/*',
                        'paddle-stubs/nn/utils/*',
                        'paddle-stubs/onnx/*',
                        'paddle-stubs/optimizer/*',
                        'paddle-stubs/profiler/*',
                        'paddle-stubs/reader/*',
                        'paddle-stubs/reader/tests/*',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/regularizer.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/signal.pyi',
                        'paddle-stubs/sparse/*',
                        'paddle-stubs/sparse/functional/*',
                        'paddle-stubs/sparse/layer/*',
                        'paddle-stubs/static/*',
                        'paddle-stubs/static/amp/*',
                        'paddle-stubs/static/nn/*',
                        'paddle-stubs/static/sparsity/*',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/sysconfig.pyi',
                        'paddle-stubs/tensor/*',
                        'paddle-stubs/text/*',
                        'paddle-stubs/text/datasets/*',
                        'paddle-stubs/utils/*',
                        'paddle-stubs/utils/cpp_extension/*',
                        'paddle-stubs/utils/gast/*',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/version.pyi',
                        'paddle-stubs/vision/*',
                        'paddle-stubs/vision/datasets/*',
                        'paddle-stubs/vision/models/*',
                        'paddle-stubs/vision/transforms/*']}

install_requires = \
['paddlepaddle>=2.3.0,<3.0.0', 'typing-extensions>=4.3.0,<5.0.0']

setup_kwargs = {
    'name': 'paddlepaddle-stubs',
    'version': '2.3.1a4',
    'description': '',
    'long_description': '# PaddlePaddle Stubs <sup>WIP</sup>\n\nA stubs package as described in [PEP 561](https://peps.python.org/pep-0561/) for [PaddlePaddle](https://github.com/PaddlePaddle/Paddle).\n\n<p align="center">\n   <a href="https://python.org/" target="_blank"><img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/paddlepaddle-stubs?logo=python&style=flat-square"></a>\n   <a href="https://pypi.org/project/paddlepaddle-stubs/" target="_blank"><img src="https://img.shields.io/pypi/v/paddlepaddle-stubs?style=flat-square" alt="pypi"></a>\n   <a href="https://pypi.org/project/paddlepaddle-stubs/" target="_blank"><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/paddlepaddle-stubs?style=flat-square"></a>\n   <a href="LICENSE"><img alt="LICENSE" src="https://img.shields.io/github/license/cattidea/paddlepaddle-stubs?style=flat-square"></a>\n   <a href="https://github.com/psf/black"><img alt="black" src="https://img.shields.io/badge/code%20style-black-000000?style=flat-square"></a>\n   <a href="https://gitmoji.dev"><img src="https://img.shields.io/badge/gitmoji-%20😜%20😍-FFDD67?style=flat-square" alt="Gitmoji"></a>\n</p>\n\n目前仅针对 [Pyright](https://github.com/microsoft/pyright) 进行了编写和测试，尚未支持 [Mypy](https://github.com/python/mypy)（Mypy 相对于 Pyright 太难用了，缺失功能太多），因此目前可能仅仅与 VS Code 的 Pylance 扩展一起工作良好～\n\n> **Note**\n>\n> 本 repo 非运行时库，因此本 repo 中所有示例和单测可能在运行时并不能正常运行，仅仅是为了更加全面和方便对类型进行检查而已。\n\n## Usage\n\n```bash\npip install paddlepaddle-stubs --pre\n```\n\n此时再打开编辑器，查看编辑器的类型提示～～～\n\nVS Code 推荐配置：\n\n```jsonc\n{\n   "python.languageServer": "Pylance",\n   // 现在有一些类型在 strict mode 工作的并不是很好，推荐先使用 basic mode\n   "python.analysis.typeCheckingMode": "basic",\n   "python.analysis.inlayHints.functionReturnTypes": true,\n   "python.analysis.inlayHints.variableTypes": true\n}\n```\n\n## Status\n\n起步阶段，最低支持 Python3.7，目前基于 PaddlePaddle 2.3.1 开发，第一个可用版本应当是 2.3.1 版本或者更晚的 2.4 版本～\n\n## Roadmap\n\nSee [paddlepaddle-stubs 2.3.1 Roadmap](https://github.com/orgs/cattidea/projects/3)\n\n### 2.3.1 alpha\n\n> **Note**\n>\n> 此时本 repo 可 public，并发布到 PyPI\n\n-  [x] 通过 basic mode 的类型检查\n-  [x] 完善全部 P1 级别的类型信息（strict 下工作良好）\n\n### 2.3.1 beta\n\n-  [ ] 完善全部 P2 级别的类型信息（strict 下工作良好）\n-  [ ] [官网示例高层 API 搭建 MNIST 示例代码](./examples/mnist_example.py)在 strict 模式下工作良好\n\n### Future\n\n之后应该是一边升级到新版本（2.4.0），一边继续完善 P3、P4、P5 级别的类型信息（strict 下工作良好）\n\n要添加的还有很多，各个 API 类型信息需要仔细填写（修改自动生成的 `Any`，添加返回值类型），有兴趣的小伙伴可以一起来参与呀～\n',
    'author': 'Nyakku Shigure',
    'author_email': 'sigure.qaq@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/cattidea/paddlepaddle-stubs',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
